AccountWithRestoreAccess class

Describes an AWS customer account authorized to restore a snapshot.

Constructors

AccountWithRestoreAccess({String? accountAlias, String? accountId})
AccountWithRestoreAccess.fromXml(XmlElement elem)
factory

Properties

accountAlias → String?
The identifier of an AWS support account authorized to restore a snapshot. For AWS support, the identifier is amazon-redshift-support.
final
accountId → String?
The identifier of an AWS customer account authorized to restore a snapshot.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited