AvailabilityZone class

Describes an availability zone.

Constructors

AvailabilityZone({String? name, List<SupportedPlatform>? supportedPlatforms})
AvailabilityZone.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the availability zone.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedPlatforms → List<SupportedPlatform>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited