BatchModifyClusterSnapshotsOutputMessage class

Properties

errors → List<SnapshotErrorMessage>?
A list of any errors returned.
final
hashCode → int
The hash code for this object.
no setterinherited
resources → List<String>?
A list of the snapshots that were modified.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited