Cluster class

Describes a cluster.

Constructors

Cluster({bool? allowVersionUpgrade, int? automatedSnapshotRetentionPeriod, String? availabilityZone, String? availabilityZoneRelocationStatus, String? clusterAvailabilityStatus, DateTime? clusterCreateTime, String? clusterIdentifier, String? clusterNamespaceArn, List<ClusterNode>? clusterNodes, List<ClusterParameterGroupStatus>? clusterParameterGroups, String? clusterPublicKey, String? clusterRevisionNumber, List<ClusterSecurityGroupMembership>? clusterSecurityGroups, ClusterSnapshotCopyStatus? clusterSnapshotCopyStatus, String? clusterStatus, String? clusterSubnetGroupName, String? clusterVersion, String? dBName, DataTransferProgress? dataTransferProgress, List<DeferredMaintenanceWindow>? deferredMaintenanceWindows, ElasticIpStatus? elasticIpStatus, String? elasticResizeNumberOfNodeOptions, bool? encrypted, Endpoint? endpoint, bool? enhancedVpcRouting, DateTime? expectedNextSnapshotScheduleTime, String? expectedNextSnapshotScheduleTimeStatus, HsmStatus? hsmStatus, List<ClusterIamRole>? iamRoles, String? kmsKeyId, String? maintenanceTrackName, int? manualSnapshotRetentionPeriod, String? masterUsername, String? modifyStatus, DateTime? nextMaintenanceWindowStartTime, String? nodeType, int? numberOfNodes, List<String>? pendingActions, PendingModifiedValues? pendingModifiedValues, String? preferredMaintenanceWindow, bool? publiclyAccessible, ResizeInfo? resizeInfo, RestoreStatus? restoreStatus, String? snapshotScheduleIdentifier, ScheduleState? snapshotScheduleState, List<Tag>? tags, String? vpcId, List<VpcSecurityGroupMembership>? vpcSecurityGroups})
Cluster.fromXml(XmlElement elem)
factory

Properties

allowVersionUpgrade → bool?
A boolean value that, if true, indicates that major version upgrades will be applied automatically to the cluster during the maintenance window.
final
automatedSnapshotRetentionPeriod → int?
The number of days that automatic cluster snapshots are retained.
final
availabilityZone → String?
The name of the Availability Zone in which the cluster is located.
final
availabilityZoneRelocationStatus → String?
Describes the status of the Availability Zone relocation operation.
final
clusterAvailabilityStatus → String?
The availability status of the cluster for queries. Possible values are the following:
final
clusterCreateTime → DateTime?
The date and time that the cluster was created.
final
clusterIdentifier → String?
The unique identifier of the cluster.
final
clusterNamespaceArn → String?
The namespace Amazon Resource Name (ARN) of the cluster.
final
clusterNodes → List<ClusterNode>?
The nodes in the cluster.
final
clusterParameterGroups → List<ClusterParameterGroupStatus>?
The list of cluster parameter groups that are associated with this cluster. Each parameter group in the list is returned with its status.
final
clusterPublicKey → String?
The public key for the cluster.
final
clusterRevisionNumber → String?
The specific revision number of the database in the cluster.
final
clusterSecurityGroups → List<ClusterSecurityGroupMembership>?
A list of cluster security group that are associated with the cluster. Each security group is represented by an element that contains ClusterSecurityGroup.Name and ClusterSecurityGroup.Status subelements.
final
clusterSnapshotCopyStatus → ClusterSnapshotCopyStatus?
A value that returns the destination region and retention period that are configured for cross-region snapshot copy.
final
clusterStatus → String?
The current state of the cluster. Possible values are the following:
final
clusterSubnetGroupName → String?
The name of the subnet group that is associated with the cluster. This parameter is valid only when the cluster is in a VPC.
final
clusterVersion → String?
The version ID of the Amazon Redshift engine that is running on the cluster.
final
dataTransferProgress → DataTransferProgress?
final
dBName → String?
The name of the initial database that was created when the cluster was created. This same name is returned for the life of the cluster. If an initial database was not specified, a database named devdev was created by default.
final
deferredMaintenanceWindows → List<DeferredMaintenanceWindow>?
Describes a group of DeferredMaintenanceWindow objects.
final
elasticIpStatus → ElasticIpStatus?
The status of the elastic IP (EIP) address.
final
elasticResizeNumberOfNodeOptions → String?
The number of nodes that you can resize the cluster to with the elastic resize method.
final
encrypted → bool?
A boolean value that, if true, indicates that data in the cluster is encrypted at rest.
final
endpoint → Endpoint?
The connection endpoint.
final
enhancedVpcRouting → bool?
An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.
final
expectedNextSnapshotScheduleTime → DateTime?
The date and time when the next snapshot is expected to be taken for clusters with a valid snapshot schedule and backups enabled.
final
expectedNextSnapshotScheduleTimeStatus → String?
The status of next expected snapshot for clusters having a valid snapshot schedule and backups enabled. Possible values are the following:
final
hashCode → int
The hash code for this object.
no setterinherited
hsmStatus → HsmStatus?
A value that reports whether the Amazon Redshift cluster has finished applying any hardware security module (HSM) settings changes specified in a modify cluster command.
final
iamRoles → List<ClusterIamRole>?
A list of AWS Identity and Access Management (IAM) roles that can be used by the cluster to access other AWS services.
final
kmsKeyId → String?
The AWS Key Management Service (AWS KMS) key ID of the encryption key used to encrypt data in the cluster.
final
maintenanceTrackName → String?
The name of the maintenance track for the cluster.
final
manualSnapshotRetentionPeriod → int?
The default number of days to retain a manual snapshot. If the value is -1, the snapshot is retained indefinitely. This setting doesn't change the retention period of existing snapshots.
final
masterUsername → String?
The master user name for the cluster. This name is used to connect to the database that is specified in the DBName parameter.
final
modifyStatus → String?
The status of a modify operation, if any, initiated for the cluster.
final
nextMaintenanceWindowStartTime → DateTime?
The date and time in UTC when system maintenance can begin.
final
nodeType → String?
The node type for the nodes in the cluster.
final
numberOfNodes → int?
The number of compute nodes in the cluster.
final
pendingActions → List<String>?
Cluster operations that are waiting to be started.
final
pendingModifiedValues → PendingModifiedValues?
A value that, if present, indicates that changes to the cluster are pending. Specific pending changes are identified by subelements.
final
preferredMaintenanceWindow → String?
The weekly time range, in Universal Coordinated Time (UTC), during which system maintenance can occur.
final
publiclyAccessible → bool?
A boolean value that, if true, indicates that the cluster can be accessed from a public network.
final
resizeInfo → ResizeInfo?
Returns the following:
final
restoreStatus → RestoreStatus?
A value that describes the status of a cluster restore action. This parameter returns null if the cluster was not created by restoring a snapshot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotScheduleIdentifier → String?
A unique identifier for the cluster snapshot schedule.
final
snapshotScheduleState → ScheduleState?
The current state of the cluster snapshot schedule.
final
tags → List<Tag>?
The list of tags for the cluster.
final
vpcId → String?
The identifier of the VPC the cluster is in, if the cluster is in a VPC.
final
vpcSecurityGroups → List<VpcSecurityGroupMembership>?
A list of Amazon Virtual Private Cloud (Amazon VPC) security groups that are associated with the cluster. This parameter is returned only if the cluster is in a VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited