ClusterDbRevision class

Describes a ClusterDbRevision.

Constructors

ClusterDbRevision({String? clusterIdentifier, String? currentDatabaseRevision, DateTime? databaseRevisionReleaseDate, List<RevisionTarget>? revisionTargets})
ClusterDbRevision.fromXml(XmlElement elem)
factory

Properties

clusterIdentifier → String?
The unique identifier of the cluster.
final
currentDatabaseRevision → String?
A string representing the current cluster version.
final
databaseRevisionReleaseDate → DateTime?
The date on which the database revision was released.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionTargets → List<RevisionTarget>?
A list of RevisionTarget objects, where each object describes the database revision that a cluster can be updated to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited