ClusterIamRole class

An AWS Identity and Access Management (IAM) role that can be used by the associated Amazon Redshift cluster to access other AWS services.

Constructors

ClusterIamRole({String? applyStatus, String? iamRoleArn})
ClusterIamRole.fromXml(XmlElement elem)
factory

Properties

applyStatus → String?
A value that describes the status of the IAM role's association with an Amazon Redshift cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRoleArn → String?
The Amazon Resource Name (ARN) of the IAM role, for example, arn:aws:iam::123456789012:role/RedshiftCopyUnload.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited