ClusterParameterGroup class

Describes a parameter group.

Constructors

ClusterParameterGroup({String? description, String? parameterGroupFamily, String? parameterGroupName, List<Tag>? tags})
ClusterParameterGroup.fromXml(XmlElement elem)
factory

Properties

description → String?
The description of the parameter group.
final
hashCode → int
The hash code for this object.
no setterinherited
parameterGroupFamily → String?
The name of the cluster parameter group family that this cluster parameter group is compatible with.
final
parameterGroupName → String?
The name of the cluster parameter group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The list of tags for the cluster parameter group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited