ClusterParameterGroupNameMessage class

Constructors

ClusterParameterGroupNameMessage({String? parameterGroupName, String? parameterGroupStatus})
ClusterParameterGroupNameMessage.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameterGroupName → String?
The name of the cluster parameter group.
final
parameterGroupStatus → String?
The status of the parameter group. For example, if you made a change to a parameter group name-value pair, then the change could be pending a reboot of an associated cluster.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited