ClusterParameterGroupStatus class

Describes the status of a parameter group.

Constructors

ClusterParameterGroupStatus({List<ClusterParameterStatus>? clusterParameterStatusList, String? parameterApplyStatus, String? parameterGroupName})
ClusterParameterGroupStatus.fromXml(XmlElement elem)
factory

Properties

clusterParameterStatusList → List<ClusterParameterStatus>?
The list of parameter statuses.
final
hashCode → int
The hash code for this object.
no setterinherited
parameterApplyStatus → String?
The status of parameter updates.
final
parameterGroupName → String?
The name of the cluster parameter group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited