ClusterParameterStatus class

Describes the status of a parameter group.

Constructors

ClusterParameterStatus({String? parameterApplyErrorDescription, String? parameterApplyStatus, String? parameterName})
ClusterParameterStatus.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameterApplyErrorDescription → String?
The error that prevented the parameter from being applied to the database.
final
parameterApplyStatus → String?
The status of the parameter that indicates whether the parameter is in sync with the database, waiting for a cluster reboot, or encountered an error when being applied.
final
parameterName → String?
The name of the parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited