ClusterSnapshotCopyStatus class

Returns the destination region and retention period that are configured for cross-region snapshot copy.

Constructors

ClusterSnapshotCopyStatus({String? destinationRegion, int? manualSnapshotRetentionPeriod, int? retentionPeriod, String? snapshotCopyGrantName})
ClusterSnapshotCopyStatus.fromXml(XmlElement elem)
factory

Properties

destinationRegion → String?
The destination region that snapshots are automatically copied to when cross-region snapshot copy is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
manualSnapshotRetentionPeriod → int?
The number of days that automated snapshots are retained in the destination region after they are copied from a source region. If the value is -1, the manual snapshot is retained indefinitely.
final
retentionPeriod → int?
The number of days that automated snapshots are retained in the destination region after they are copied from a source region.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotCopyGrantName → String?
The name of the snapshot copy grant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited