ClusterSubnetGroup class

Describes a subnet group.

Constructors

ClusterSubnetGroup({String? clusterSubnetGroupName, String? description, String? subnetGroupStatus, List<Subnet>? subnets, List<Tag>? tags, String? vpcId})
ClusterSubnetGroup.fromXml(XmlElement elem)
factory

Properties

clusterSubnetGroupName → String?
The name of the cluster subnet group.
final
description → String?
The description of the cluster subnet group.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetGroupStatus → String?
The status of the cluster subnet group. Possible values are Complete, Incomplete and Invalid.
final
subnets → List<Subnet>?
A list of the VPC Subnet elements.
final
tags → List<Tag>?
The list of tags for the cluster subnet group.
final
vpcId → String?
The VPC ID of the cluster subnet group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited