ClusterVersion class

Describes a cluster version, including the parameter group family and description of the version.

Constructors

ClusterVersion({String? clusterParameterGroupFamily, String? clusterVersion, String? description})
ClusterVersion.fromXml(XmlElement elem)
factory

Properties

clusterParameterGroupFamily → String?
The name of the cluster parameter group family for the cluster.
final
clusterVersion → String?
The version number used by the cluster.
final
description → String?
The description of the cluster version.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited