DataTransferProgress class

Describes the status of a cluster while it is in the process of resizing with an incremental resize.

Constructors

DataTransferProgress({double? currentRateInMegaBytesPerSecond, int? dataTransferredInMegaBytes, int? elapsedTimeInSeconds, int? estimatedTimeToCompletionInSeconds, String? status, int? totalDataInMegaBytes})
DataTransferProgress.fromXml(XmlElement elem)
factory

Properties

currentRateInMegaBytesPerSecond → double?
Describes the data transfer rate in MB's per second.
final
dataTransferredInMegaBytes → int?
Describes the total amount of data that has been transfered in MB's.
final
elapsedTimeInSeconds → int?
Describes the number of seconds that have elapsed during the data transfer.
final
estimatedTimeToCompletionInSeconds → int?
Describes the estimated number of seconds remaining to complete the transfer.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Describes the status of the cluster. While the transfer is in progress the status is transferringdata.
final
totalDataInMegaBytes → int?
Describes the total amount of data to be transfered in megabytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited