DeleteClusterSnapshotMessage class

Constructors

DeleteClusterSnapshotMessage({required String snapshotIdentifier, String? snapshotClusterIdentifier})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotClusterIdentifier → String?
The unique identifier of the cluster the snapshot was created from. This parameter is required if your IAM user has a policy containing a snapshot resource element that specifies anything other than * for the cluster name.
final
snapshotIdentifier → String
The unique identifier of the manual snapshot to be deleted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited