EC2SecurityGroup class

Describes an Amazon EC2 security group.

Constructors

EC2SecurityGroup({String? eC2SecurityGroupName, String? eC2SecurityGroupOwnerId, String? status, List<Tag>? tags})
EC2SecurityGroup.fromXml(XmlElement elem)
factory

Properties

eC2SecurityGroupName → String?
The name of the EC2 Security Group.
final
eC2SecurityGroupOwnerId → String?
The AWS ID of the owner of the EC2 security group specified in the EC2SecurityGroupName field.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the EC2 security group.
final
tags → List<Tag>?
The list of tags for the EC2 security group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited