Endpoint class

Describes a connection endpoint.

Constructors

Endpoint({String? address, int? port, List<SpartaProxyVpcEndpoint>? vpcEndpoints})
Endpoint.fromXml(XmlElement elem)
factory

Properties

address → String?
The DNS address of the Cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
port → int?
The port that the database engine is listening on.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcEndpoints → List<SpartaProxyVpcEndpoint>?
Describes a connection endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited