Event class

Describes an event.

Constructors

Event({DateTime? date, List<String>? eventCategories, String? eventId, String? message, String? severity, String? sourceIdentifier, SourceType? sourceType})
Event.fromXml(XmlElement elem)
factory

Properties

date → DateTime?
The date and time of the event.
final
eventCategories → List<String>?
A list of the event categories.
final
eventId → String?
The identifier of the event.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The text of this event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → String?
The severity of the event.
final
sourceIdentifier → String?
The identifier for the source of the event.
final
sourceType → SourceType?
The source type for this event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited