EventInfoMap class

Describes event information.

Constructors

EventInfoMap({List<String>? eventCategories, String? eventDescription, String? eventId, String? severity})
EventInfoMap.fromXml(XmlElement elem)
factory

Properties

eventCategories → List<String>?
The category of an Amazon Redshift event.
final
eventDescription → String?
The description of an Amazon Redshift event.
final
eventId → String?
The identifier of an Amazon Redshift event.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → String?
The severity of the event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited