EventSubscription class

Describes event subscriptions.

Constructors

EventSubscription({String? custSubscriptionId, String? customerAwsId, bool? enabled, List<String>? eventCategoriesList, String? severity, String? snsTopicArn, List<String>? sourceIdsList, String? sourceType, String? status, DateTime? subscriptionCreationTime, List<Tag>? tags})
EventSubscription.fromXml(XmlElement elem)
factory

Properties

customerAwsId → String?
The AWS customer account associated with the Amazon Redshift event notification subscription.
final
custSubscriptionId → String?
The name of the Amazon Redshift event notification subscription.
final
enabled → bool?
A boolean value indicating whether the subscription is enabled; true indicates that the subscription is enabled.
final
eventCategoriesList → List<String>?
The list of Amazon Redshift event categories specified in the event notification subscription.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → String?
The event severity specified in the Amazon Redshift event notification subscription.
final
snsTopicArn → String?
The Amazon Resource Name (ARN) of the Amazon SNS topic used by the event notification subscription.
final
sourceIdsList → List<String>?
A list of the sources that publish events to the Amazon Redshift event notification subscription.
final
sourceType → String?
The source type of the events returned by the Amazon Redshift event notification, such as cluster, cluster-snapshot, cluster-parameter-group, cluster-security-group, or scheduled-action.
final
status → String?
The status of the Amazon Redshift event notification subscription.
final
subscriptionCreationTime → DateTime?
The date and time the Amazon Redshift event notification subscription was created.
final
tags → List<Tag>?
The list of tags for the event subscription.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited