HsmStatus class

Describes the status of changes to HSM settings.

Constructors

HsmStatus({String? hsmClientCertificateIdentifier, String? hsmConfigurationIdentifier, String? status})
HsmStatus.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hsmClientCertificateIdentifier → String?
Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM.
final
hsmConfigurationIdentifier → String?
Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Reports whether the Amazon Redshift cluster has finished applying any HSM settings changes specified in a modify cluster command.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited