LoggingStatus class

Describes the status of logging for a cluster.

Constructors

LoggingStatus({String? bucketName, String? lastFailureMessage, DateTime? lastFailureTime, DateTime? lastSuccessfulDeliveryTime, bool? loggingEnabled, String? s3KeyPrefix})
LoggingStatus.fromXml(XmlElement elem)
factory

Properties

bucketName → String?
The name of the S3 bucket where the log files are stored.
final
hashCode → int
The hash code for this object.
no setterinherited
lastFailureMessage → String?
The message indicating that logs failed to be delivered.
final
lastFailureTime → DateTime?
The last time when logs failed to be delivered.
final
lastSuccessfulDeliveryTime → DateTime?
The last time that logs were delivered.
final
loggingEnabled → bool?
true if logging is on, false if logging is off.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3KeyPrefix → String?
The prefix applied to the log file names.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited