NodeConfigurationOption class

A list of node configurations.

Constructors

NodeConfigurationOption({double? estimatedDiskUtilizationPercent, Mode? mode, String? nodeType, int? numberOfNodes})
NodeConfigurationOption.fromXml(XmlElement elem)
factory

Properties

estimatedDiskUtilizationPercent → double?
The estimated disk utilizaton percentage.
final
hashCode → int
The hash code for this object.
no setterinherited
mode → Mode?
The category of the node configuration recommendation.
final
nodeType → String?
The node type, such as, "ds2.8xlarge".
final
numberOfNodes → int?
The number of nodes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited