OrderableClusterOption class

Describes an orderable cluster option.

Constructors

OrderableClusterOption({List<AvailabilityZone>? availabilityZones, String? clusterType, String? clusterVersion, String? nodeType})
OrderableClusterOption.fromXml(XmlElement elem)
factory

Properties

availabilityZones → List<AvailabilityZone>?
A list of availability zones for the orderable cluster.
final
clusterType → String?
The cluster type, for example multi-node.
final
clusterVersion → String?
The version of the orderable cluster.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeType → String?
The node type for the orderable cluster.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited