Parameter class

Describes a parameter in a cluster parameter group.

Constructors

Parameter({String? allowedValues, ParameterApplyType? applyType, String? dataType, String? description, bool? isModifiable, String? minimumEngineVersion, String? parameterName, String? parameterValue, String? source})
Parameter.fromXml(XmlElement elem)
factory

Properties

allowedValues → String?
The valid range of values for the parameter.
final
applyType → ParameterApplyType?
Specifies how to apply the WLM configuration parameter. Some properties can be applied dynamically, while other properties require that any associated clusters be rebooted for the configuration changes to be applied. For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.
final
dataType → String?
The data type of the parameter.
final
description → String?
A description of the parameter.
final
hashCode → int
The hash code for this object.
no setterinherited
isModifiable → bool?
If true, the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.
final
minimumEngineVersion → String?
The earliest engine version to which the parameter can apply.
final
parameterName → String?
The name of the parameter.
final
parameterValue → String?
The value of the parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
The source of the parameter value, such as "engine-default" or "user".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited