PendingModifiedValues class

Describes cluster attributes that are in a pending state. A change to one or more the attributes was requested and is in progress or will be applied.

Constructors

PendingModifiedValues({int? automatedSnapshotRetentionPeriod, String? clusterIdentifier, String? clusterType, String? clusterVersion, String? encryptionType, bool? enhancedVpcRouting, String? maintenanceTrackName, String? masterUserPassword, String? nodeType, int? numberOfNodes, bool? publiclyAccessible})
PendingModifiedValues.fromXml(XmlElement elem)
factory

Properties

automatedSnapshotRetentionPeriod → int?
The pending or in-progress change of the automated snapshot retention period.
final
clusterIdentifier → String?
The pending or in-progress change of the new identifier for the cluster.
final
clusterType → String?
The pending or in-progress change of the cluster type.
final
clusterVersion → String?
The pending or in-progress change of the service version.
final
encryptionType → String?
The encryption type for a cluster. Possible values are: KMS and None.
final
enhancedVpcRouting → bool?
An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.
final
hashCode → int
The hash code for this object.
no setterinherited
maintenanceTrackName → String?
The name of the maintenance track that the cluster will change to during the next maintenance window.
final
masterUserPassword → String?
The pending or in-progress change of the master user password for the cluster.
final
nodeType → String?
The pending or in-progress change of the cluster's node type.
final
numberOfNodes → int?
The pending or in-progress change of the number of nodes in the cluster.
final
publiclyAccessible → bool?
The pending or in-progress change of the ability to connect to the cluster from the public network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited