RecurringCharge class

Describes a recurring charge.

Constructors

RecurringCharge({double? recurringChargeAmount, String? recurringChargeFrequency})
RecurringCharge.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recurringChargeAmount → double?
The amount charged per the period of time specified by the recurring charge frequency.
final
recurringChargeFrequency → String?
The frequency at which the recurring charge amount is applied.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited