ReservedNode class

Describes a reserved node. You can call the DescribeReservedNodeOfferings API to obtain the available reserved node offerings.

Constructors

ReservedNode({String? currencyCode, int? duration, double? fixedPrice, int? nodeCount, String? nodeType, String? offeringType, List<RecurringCharge>? recurringCharges, String? reservedNodeId, String? reservedNodeOfferingId, ReservedNodeOfferingType? reservedNodeOfferingType, DateTime? startTime, String? state, double? usagePrice})
ReservedNode.fromXml(XmlElement elem)
factory

Properties

currencyCode → String?
The currency code for the reserved cluster.
final
duration → int?
The duration of the node reservation in seconds.
final
fixedPrice → double?
The fixed cost Amazon Redshift charges you for this reserved node.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeCount → int?
The number of reserved compute nodes.
final
nodeType → String?
The node type of the reserved node.
final
offeringType → String?
The anticipated utilization of the reserved node, as defined in the reserved node offering.
final
recurringCharges → List<RecurringCharge>?
The recurring charges for the reserved node.
final
reservedNodeId → String?
The unique identifier for the reservation.
final
reservedNodeOfferingId → String?
The identifier for the reserved node offering.
final
reservedNodeOfferingType → ReservedNodeOfferingType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The time the reservation started. You purchase a reserved node offering for a duration. This is the start time of that duration.
final
state → String?
The state of the reserved compute node.
final
usagePrice → double?
The hourly rate Amazon Redshift charges you for this reserved node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited