ReservedNodeOffering class

Describes a reserved node offering.

Constructors

ReservedNodeOffering({String? currencyCode, int? duration, double? fixedPrice, String? nodeType, String? offeringType, List<RecurringCharge>? recurringCharges, String? reservedNodeOfferingId, ReservedNodeOfferingType? reservedNodeOfferingType, double? usagePrice})
ReservedNodeOffering.fromXml(XmlElement elem)
factory

Properties

currencyCode → String?
The currency code for the compute nodes offering.
final
duration → int?
The duration, in seconds, for which the offering will reserve the node.
final
fixedPrice → double?
The upfront fixed charge you will pay to purchase the specific reserved node offering.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeType → String?
The node type offered by the reserved node offering.
final
offeringType → String?
The anticipated utilization of the reserved node, as defined in the reserved node offering.
final
recurringCharges → List<RecurringCharge>?
The charge to your account regardless of whether you are creating any clusters using the node offering. Recurring charges are only in effect for heavy-utilization reserved nodes.
final
reservedNodeOfferingId → String?
The offering identifier.
final
reservedNodeOfferingType → ReservedNodeOfferingType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usagePrice → double?
The rate you are charged for each hour the cluster that is using the offering is running.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited