ResizeInfo class

Describes a resize operation.

Constructors

ResizeInfo({bool? allowCancelResize, String? resizeType})
ResizeInfo.fromXml(XmlElement elem)
factory

Properties

allowCancelResize → bool?
A boolean value indicating if the resize operation can be cancelled.
final
hashCode → int
The hash code for this object.
no setterinherited
resizeType → String?
Returns the value ClassicResize.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited