RestoreStatus class

Describes the status of a cluster restore action. Returns null if the cluster was not created by restoring a snapshot.

Constructors

RestoreStatus({double? currentRestoreRateInMegaBytesPerSecond, int? elapsedTimeInSeconds, int? estimatedTimeToCompletionInSeconds, int? progressInMegaBytes, int? snapshotSizeInMegaBytes, String? status})
RestoreStatus.fromXml(XmlElement elem)
factory

Properties

currentRestoreRateInMegaBytesPerSecond → double?
The number of megabytes per second being transferred from the backup storage. Returns the average rate for a completed backup. This field is only updated when you restore to DC2 and DS2 node types.
final
elapsedTimeInSeconds → int?
The amount of time an in-progress restore has been running, or the amount of time it took a completed restore to finish. This field is only updated when you restore to DC2 and DS2 node types.
final
estimatedTimeToCompletionInSeconds → int?
The estimate of the time remaining before the restore will complete. Returns 0 for a completed restore. This field is only updated when you restore to DC2 and DS2 node types.
final
hashCode → int
The hash code for this object.
no setterinherited
progressInMegaBytes → int?
The number of megabytes that have been transferred from snapshot storage. This field is only updated when you restore to DC2 and DS2 node types.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotSizeInMegaBytes → int?
The size of the set of snapshot data used to restore the cluster. This field is only updated when you restore to DC2 and DS2 node types.
final
status → String?
The status of the restore action. Returns starting, restoring, completed, or failed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited