RevisionTarget class

Describes a RevisionTarget.

Constructors

RevisionTarget({String? databaseRevision, DateTime? databaseRevisionReleaseDate, String? description})
RevisionTarget.fromXml(XmlElement elem)
factory

Properties

databaseRevision → String?
A unique string that identifies the version to update the cluster to. You can use this value in ModifyClusterDbRevision.
final
databaseRevisionReleaseDate → DateTime?
The date on which the database revision was released.
final
description → String?
A string that describes the changes and features that will be applied to the cluster when it is updated to the corresponding ClusterDbRevision.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited