ScheduledAction class

Describes a scheduled action. You can use a scheduled action to trigger some Amazon Redshift API operations on a schedule. For information about which API operations can be scheduled, see ScheduledActionType.

Constructors

ScheduledAction({DateTime? endTime, String? iamRole, List<DateTime>? nextInvocations, String? schedule, String? scheduledActionDescription, String? scheduledActionName, DateTime? startTime, ScheduledActionState? state, ScheduledActionType? targetAction})
ScheduledAction.fromXml(XmlElement elem)
factory

Properties

endTime → DateTime?
The end time in UTC when the schedule is no longer active. After this time, the scheduled action does not trigger.
final
hashCode → int
The hash code for this object.
no setterinherited
iamRole → String?
The IAM role to assume to run the scheduled action. This IAM role must have permission to run the Amazon Redshift API operation in the scheduled action. This IAM role must allow the Amazon Redshift scheduler (Principal scheduler.redshift.amazonaws.com) to assume permissions on your behalf. For more information about the IAM role to use with the Amazon Redshift scheduler, see Using Identity-Based Policies for Amazon Redshift in the Amazon Redshift Cluster Management Guide.
final
nextInvocations → List<DateTime>?
List of times when the scheduled action will run.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule → String?
The schedule for a one-time (at format) or recurring (cron format) scheduled action. Schedule invocations must be separated by at least one hour.
final
scheduledActionDescription → String?
The description of the scheduled action.
final
scheduledActionName → String?
The name of the scheduled action.
final
startTime → DateTime?
The start time in UTC when the schedule is active. Before this time, the scheduled action does not trigger.
final
state → ScheduledActionState?
The state of the scheduled action. For example, DISABLED.
final
targetAction → ScheduledActionType?
A JSON format string of the Amazon Redshift API operation with input parameters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited