ScheduledActionFilter class

A set of elements to filter the returned scheduled actions.

Constructors

ScheduledActionFilter({required ScheduledActionFilterName name, required List<String> values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → ScheduledActionFilterName
The type of element to filter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
List of values. Compare if the value (of type defined by Name) equals an item in the list of scheduled actions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited