ScheduledActionType class

The action type that specifies an Amazon Redshift API operation that is supported by the Amazon Redshift scheduler.

Constructors

ScheduledActionType({PauseClusterMessage? pauseCluster, ResizeClusterMessage? resizeCluster, ResumeClusterMessage? resumeCluster})
ScheduledActionType.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pauseCluster → PauseClusterMessage?
An action that runs a PauseCluster API operation.
final
resizeCluster → ResizeClusterMessage?
An action that runs a ResizeCluster API operation.
final
resumeCluster → ResumeClusterMessage?
An action that runs a ResumeCluster API operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited