Snapshot class

Describes a snapshot.

Constructors

Snapshot({List<AccountWithRestoreAccess>? accountsWithRestoreAccess, double? actualIncrementalBackupSizeInMegaBytes, String? availabilityZone, double? backupProgressInMegaBytes, DateTime? clusterCreateTime, String? clusterIdentifier, String? clusterVersion, double? currentBackupRateInMegaBytesPerSecond, String? dBName, int? elapsedTimeInSeconds, bool? encrypted, bool? encryptedWithHSM, String? engineFullVersion, bool? enhancedVpcRouting, int? estimatedSecondsToCompletion, String? kmsKeyId, String? maintenanceTrackName, int? manualSnapshotRemainingDays, int? manualSnapshotRetentionPeriod, String? masterUsername, String? nodeType, int? numberOfNodes, String? ownerAccount, int? port, List<String>? restorableNodeTypes, DateTime? snapshotCreateTime, String? snapshotIdentifier, DateTime? snapshotRetentionStartTime, String? snapshotType, String? sourceRegion, String? status, List<Tag>? tags, double? totalBackupSizeInMegaBytes, String? vpcId})
Snapshot.fromXml(XmlElement elem)
factory

Properties

accountsWithRestoreAccess → List<AccountWithRestoreAccess>?
A list of the AWS customer accounts authorized to restore the snapshot. Returns null if no accounts are authorized. Visible only to the snapshot owner.
final
actualIncrementalBackupSizeInMegaBytes → double?
The size of the incremental backup.
final
availabilityZone → String?
The Availability Zone in which the cluster was created.
final
backupProgressInMegaBytes → double?
The number of megabytes that have been transferred to the snapshot backup.
final
clusterCreateTime → DateTime?
The time (UTC) when the cluster was originally created.
final
clusterIdentifier → String?
The identifier of the cluster for which the snapshot was taken.
final
clusterVersion → String?
The version ID of the Amazon Redshift engine that is running on the cluster.
final
currentBackupRateInMegaBytesPerSecond → double?
The number of megabytes per second being transferred to the snapshot backup. Returns 0 for a completed backup.
final
dBName → String?
The name of the database that was created when the cluster was created.
final
elapsedTimeInSeconds → int?
The amount of time an in-progress snapshot backup has been running, or the amount of time it took a completed backup to finish.
final
encrypted → bool?
If true, the data in the snapshot is encrypted at rest.
final
encryptedWithHSM → bool?
A boolean that indicates whether the snapshot data is encrypted using the HSM keys of the source cluster. true indicates that the data is encrypted using HSM keys.
final
engineFullVersion → String?
The cluster version of the cluster used to create the snapshot. For example, 1.0.15503.
final
enhancedVpcRouting → bool?
An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.
final
estimatedSecondsToCompletion → int?
The estimate of the time remaining before the snapshot backup will complete. Returns 0 for a completed backup.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
final
maintenanceTrackName → String?
The name of the maintenance track for the snapshot.
final
manualSnapshotRemainingDays → int?
The number of days until a manual snapshot will pass its retention period.
final
manualSnapshotRetentionPeriod → int?
The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.
final
masterUsername → String?
The master user name for the cluster.
final
nodeType → String?
The node type of the nodes in the cluster.
final
numberOfNodes → int?
The number of nodes in the cluster.
final
ownerAccount → String?
For manual snapshots, the AWS customer account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
final
port → int?
The port that the cluster is listening on.
final
restorableNodeTypes → List<String>?
The list of node types that this cluster snapshot is able to restore into.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotCreateTime → DateTime?
The time (in UTC format) when Amazon Redshift began the snapshot. A snapshot contains a copy of the cluster data as of this exact time.
final
snapshotIdentifier → String?
The snapshot identifier that is provided in the request.
final
snapshotRetentionStartTime → DateTime?
A timestamp representing the start of the retention period for the snapshot.
final
snapshotType → String?
The snapshot type. Snapshots created using CreateClusterSnapshot and CopyClusterSnapshot are of type "manual".
final
sourceRegion → String?
The source region from which the snapshot was copied.
final
status → String?
The snapshot status. The value of the status depends on the API operation used:
final
tags → List<Tag>?
The list of tags for the cluster snapshot.
final
totalBackupSizeInMegaBytes → double?
The size of the complete set of backup data that would be used to restore the cluster.
final
vpcId → String?
The VPC identifier of the cluster if the snapshot is from a cluster in a VPC. Otherwise, this field is not in the output.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited