SnapshotErrorMessage class

Describes the errors returned by a snapshot.

Constructors

SnapshotErrorMessage({String? failureCode, String? failureReason, String? snapshotClusterIdentifier, String? snapshotIdentifier})
SnapshotErrorMessage.fromXml(XmlElement elem)
factory

Properties

failureCode → String?
The failure code for the error.
final
failureReason → String?
The text message describing the error.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotClusterIdentifier → String?
A unique identifier for the cluster.
final
snapshotIdentifier → String?
A unique identifier for the snapshot returning the error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited