SnapshotSortingEntity class

Describes a sorting entity

Constructors

SnapshotSortingEntity({required SnapshotAttributeToSortBy attribute, SortByOrder? sortOrder})

Properties

attribute → SnapshotAttributeToSortBy
The category for sorting the snapshots.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOrder → SortByOrder?
The order for listing the attributes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited