Subnet class

Describes a subnet.

Constructors

Subnet({AvailabilityZone? subnetAvailabilityZone, String? subnetIdentifier, String? subnetStatus})
Subnet.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetAvailabilityZone → AvailabilityZone?
final
subnetIdentifier → String?
The identifier of the subnet.
final
subnetStatus → String?
The status of the subnet.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited