TableRestoreStatus class

Describes the status of a RestoreTableFromClusterSnapshot operation.

Constructors

TableRestoreStatus({String? clusterIdentifier, String? message, String? newTableName, int? progressInMegaBytes, DateTime? requestTime, String? snapshotIdentifier, String? sourceDatabaseName, String? sourceSchemaName, String? sourceTableName, TableRestoreStatusType? status, String? tableRestoreRequestId, String? targetDatabaseName, String? targetSchemaName, int? totalDataInMegaBytes})
TableRestoreStatus.fromXml(XmlElement elem)
factory

Properties

clusterIdentifier → String?
The identifier of the Amazon Redshift cluster that the table is being restored to.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A description of the status of the table restore request. Status values include SUCCEEDED, FAILED, CANCELED, PENDING, IN_PROGRESS.
final
newTableName → String?
The name of the table to create as a result of the table restore request.
final
progressInMegaBytes → int?
The amount of data restored to the new table so far, in megabytes (MB).
final
requestTime → DateTime?
The time that the table restore request was made, in Universal Coordinated Time (UTC).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotIdentifier → String?
The identifier of the snapshot that the table is being restored from.
final
sourceDatabaseName → String?
The name of the source database that contains the table being restored.
final
sourceSchemaName → String?
The name of the source schema that contains the table being restored.
final
sourceTableName → String?
The name of the source table being restored.
final
status → TableRestoreStatusType?
A value that describes the current state of the table restore request.
final
tableRestoreRequestId → String?
The unique identifier for the table restore request.
final
targetDatabaseName → String?
The name of the database to restore the table to.
final
targetSchemaName → String?
The name of the schema to restore the table to.
final
totalDataInMegaBytes → int?
The total amount of data to restore to the new table, in megabytes (MB).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited