TableRestoreStatusMessage class

Constructors

TableRestoreStatusMessage({String? marker, List<TableRestoreStatus>? tableRestoreStatusDetails})
TableRestoreStatusMessage.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
marker → String?
A pagination token that can be used in a subsequent DescribeTableRestoreStatus request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableRestoreStatusDetails → List<TableRestoreStatus>?
A list of status details for one or more table restore requests.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited