TrackListMessage class

Constructors

TrackListMessage({List<MaintenanceTrack>? maintenanceTracks, String? marker})
TrackListMessage.fromXml(XmlElement elem)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maintenanceTracks → List<MaintenanceTrack>?
A list of maintenance tracks output by the DescribeClusterTracks operation.
final
marker → String?
The starting point to return a set of response tracklist records. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited