UpdateTarget class

A maintenance track that you can switch the current track to.

Constructors

UpdateTarget({String? databaseVersion, String? maintenanceTrackName, List<SupportedOperation>? supportedOperations})
UpdateTarget.fromXml(XmlElement elem)
factory

Properties

databaseVersion → String?
The cluster version for the new maintenance track.
final
hashCode → int
The hash code for this object.
no setterinherited
maintenanceTrackName → String?
The name of the new maintenance track.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedOperations → List<SupportedOperation>?
A list of operations supported by the maintenance track.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited