UsageLimit class

Describes a usage limit object for a cluster.

Constructors

UsageLimit({int? amount, UsageLimitBreachAction? breachAction, String? clusterIdentifier, UsageLimitFeatureType? featureType, UsageLimitLimitType? limitType, UsageLimitPeriod? period, List<Tag>? tags, String? usageLimitId})
UsageLimit.fromXml(XmlElement elem)
factory

Properties

amount → int?
The limit amount. If time-based, this amount is in minutes. If data-based, this amount is in terabytes (TB).
final
breachAction → UsageLimitBreachAction?
The action that Amazon Redshift takes when the limit is reached. Possible values are:
final
clusterIdentifier → String?
The identifier of the cluster with a usage limit.
final
featureType → UsageLimitFeatureType?
The Amazon Redshift feature to which the limit applies.
final
hashCode → int
The hash code for this object.
no setterinherited
limitType → UsageLimitLimitType?
The type of limit. Depending on the feature type, this can be based on a time duration or data size.
final
period → UsageLimitPeriod?
The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
A list of tag instances.
final
usageLimitId → String?
The identifier of the usage limit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited